package template

const templateGitignore = `.idea
{{.Name}}
{{.Name}}.exe
{{.Name}}.exe~
`

const templateMakefile = `.PHONY : clean all ui api gen wire
gen:
ifeq ($(wildcard "webui/node_modules"),)
	buf generate
else
	buf generate --exclude-path webui/node_modules
endif

wire:
	cd gen/wire && wire

ui:
	cd webui && npm install && npm run build

api:
	go mod tidy && go build .
	./{{.Name}} api

all: gen wire ui api
`

const templateDockerfile = `FROM images.local/golang:latest

WORKDIR /app

RUN go install gitter.top/coco/protoc-gen-coco@latest &&\
    go install github.com/golang/protobuf/protoc-gen-go@latest &&\
    go install github.com/bufbuild/buf/cmd/...@latest

COPY . /app
RUN npm install ts-proto
RUN buf generate --exclude-path node_modules
RUN cd webui && npm install && npm run build &&\
         cd .. && go mod tidy && go build .

EXPOSE 38080
ENTRYPOINT [ "./filesaver", "api" ]
`

const templateDockerCompose = `version: "3"

services:
    server:
        image: xuthus5/{{.Name}}:latest
        container_name: {{.Name}}
        restart: always
        volumes:
            - /data/containers/{{.Name}}:/app/data
        ports:
            - "30001:38080"
`

const templateBuf = `version: v1
breaking:
  use:
    - FILE
lint:
  use:
    - DEFAULT
  except:
    - MINIMAL
`

const templateBufGen = `version: v1
plugins:
  - plugin: buf.build/protocolbuffers/go
    out: gen
    opt: paths=source_relative
  - plugin: coco
    out: gen
    opt: 
      - paths=source_relative
      - prefix=proto
      - project_name={{.Name}}
  - plugin: buf.build/community/stephenh-ts-proto
    out: ./webui/src/gen
    opt:
      - paths=source_relative
      - snakeToCamel=json
      - esModuleInterop=true
  - plugin: buf.build/grpc/go:v1.3.0
    out: gen
    opt:
      - paths=source_relative
      - require_unimplemented_servers=false
`

const templateBufWork = `version: v1
directories:
  - proto
`
